@@ -29,9 +29,9 @@ logger = logging.getLogger(__name__)
 MIN_DATA_SIZE_TO_HASH_IN_PROC = 1000000
 
 
-@abstracts.implementer(event.IReactive)
+@abstracts.implementer(event.IExecutive)
 class ADependencyGithubRelease(
-        event.AReactive,
+        event.AExecutive,
         metaclass=abstracts.Abstraction):
     """Github release associated with a dependency."""
 
@@ -43,10 +43,10 @@ class ADependencyGithubRelease(
 
     def __init__(
             self,
-            repo: _github.AGithubRepo,
+            repo: _github.IGithubRepo,
             version: str,
             asset_url: Optional[str] = None,
-            release: Optional[_github.AGithubRelease] = None,
+            release: Optional[_github.IGithubRelease] = None,
             loop: Optional[asyncio.AbstractEventLoop] = None,
             pool: Optional[futures.Executor] = None) -> None:
         self.repo = repo
@@ -57,10 +57,10 @@ class ADependencyGithubRelease(
         self._loop = loop
 
     @async_property(cache=True)
-    async def commit(self) -> Optional[_github.AGithubCommit]:
+    async def commit(self) -> Optional[_github.IGithubCommit]:
         """Github commit for this release."""
         try:
-            return await self.repo.commit(self.tag_name)
+            return await self.repo.commit(self.tag_name)  # type:ignore
         except gidgethub.BadRequest as e:
             if e.args[0] == "Not Found":
                 return None
@@ -72,7 +72,7 @@ class ADependencyGithubRelease(
         return utils.dt_to_utc_isoformat(await self.timestamp)
 
     @property
-    def github(self) -> _github.AGithubAPI:
+    def github(self) -> _github.IGithubAPI:
         return self.repo.github
 
     @property
@@ -80,12 +80,12 @@ class ADependencyGithubRelease(
         return MIN_DATA_SIZE_TO_HASH_IN_PROC
 
     @async_property(cache=True)
-    async def release(self) -> Optional[_github.AGithubRelease]:
+    async def release(self) -> Optional[_github.IGithubRelease]:
         """Github release."""
         if self._release:
             return self._release
         try:
-            return await self.repo.release(self.tag_name)
+            return await self.repo.release(self.tag_name)  # type:ignore
         except gidgethub.BadRequest as e:
             if e.args[0] == "Not Found":
                 return None
@@ -100,17 +100,17 @@ class ADependencyGithubRelease(
         """Release SHA."""
         if not self.asset_url:
             raise exceptions.NoReleaseAssetError(
-                f"Cannot check sha for {self.__class__.__name__}"
+                f"Cannot check sha for {self.__class__.__name__} "
                 "with no `asset_url`")
         response = await self.session.get(self.asset_url)
         logger.debug(f"SHA download: {self.asset_url}")
         return await self._hash_file_data(await response.read())
 
     @async_property(cache=True)
-    async def tag(self) -> Optional[_github.AGithubTag]:
+    async def tag(self) -> Optional[_github.IGithubTag]:
         """Github tag."""
         try:
-            return await self.repo.tag(self.tag_name)
+            return await self.repo.tag(self.tag_name)  # type:ignore
         except (gidgethub.BadRequest, _github.exceptions.TagNotFound) as e:
             do_raise = (
                 isinstance(e, gidgethub.BadRequest)
@@ -171,10 +171,7 @@ class ADependencyGithubRelease(
         hash_in_proc = self.should_hash_in_proc(data)
         start = time.perf_counter()
         sha = (
-            await self.loop.run_in_executor(
-                self.pool,
-                self.hash_file_data,
-                data)
+            await self.execute(self.hash_file_data, data)
             if hash_in_proc
             else self.hash_file_data(data))
         logger.debug(
